We ship some third-party things with Nikola.  They live here, along with their licenses.

Packages:

 * tzlocal by Lennart Regebro, CC0 license (modified)
 * datecond by Chris Warrick (Nikola contributor), 3-clause BSD license
   (modified)
